@@ -10,7 +10,7 @@ only if a new data is available.
 
 """
 
-__version__ = "1.1.5"
+__version__ = "1.1.6"
 
 import argparse
 import logging
@@ -18,6 +18,7 @@ import os
 import pickle
 import sys
 
+from collections import defaultdict
 from configparser import ConfigParser, NoOptionError
 from datetime import datetime
 
@@ -33,80 +34,42 @@ ALERTS_URL = NOAA_URL + "/text/wwv.txt"
 FLUX_URL = NOAA_URL + "/text/27-day-outlook.txt"
 
 CACHE_DIR = "/tmp/sunslack-data"
-FONT_PATH = "/System/Library/Fonts/Supplemental/Arial.ttf"
 
 logging.basicConfig(format='%(asctime)s %(levelname)s: %(message)s',
                     datefmt='%c', level=logging.INFO)
 
 
-class Config:
+def read_config(config_file):
   """Sunslack configuration example:
   [SUNSLACK]
   token: xoxb-123456789-123456789
   channel: sunflux
   cachedir: /tmp/sunflux-data
+  [ANIMATEMUF]
+  target_dir = '/tmp/muf'
+  video_file = '/tmp/muf/muf.mp4'
+  converter = '/usr/local/bin/convert.sh'
+  muf_file = '/tmp/muf_source.json'
   """
 
-  def __init__(self, config_file):
-    parser = ConfigParser()
+  _data = defaultdict(dict)
+  parser = ConfigParser()
 
-    self._token = None
-    self._channel = None
-    self._cachedir = CACHE_DIR
+  if not os.path.exists(config_file):
+    logging.error('Configuration file "%s" not found', config_file)
+    sys.exit(os.EX_CONFIG)
 
-    if not os.path.exists(config_file):
-      logging.error('Configuration file "%s" not found', config_file)
-      sys.exit(os.EX_CONFIG)
+  with open(config_file, 'r') as fdc:
+    parser.read_file(fdc)
 
-    with open(config_file, 'r') as fdc:
-      parser.read_file(fdc)
+  for name, sec in parser.items():
+    for key, value in sec.items():
+      _data[name.lower()][key] = value
 
-    try:
-      self._token = parser.get('SUNSLACK', 'token')
-      self._channel = parser.get('SUNSLACK', 'channel')
-      self._logfile = parser.get('SUNSLACK', 'logfile', fallback=None)
-      self._cachedir = parser.get('SUNSLACK', 'cachedir', fallback=CACHE_DIR)
-      self._font = parser.get('SUNSLACK', 'font', fallback=FONT_PATH)
-    except NoOptionError as err:
-      logging.error(err)
-      sys.exit(os.EX_CONFIG)
-
-    loglevel = parser.get('SUNSLACK', 'loglevel', fallback='INFO')
-    try:
-      self._loglevel = logging._checkLevel(loglevel.upper())
-    except ValueError:
-      self._loglevel = logging._checkLevel('INFO')
-
-    if not os.path.exists(self._font):
-      logging.error('Font file "%s" not found. Check your config file', self._font)
-      sys.exit(os.EX_IOERR)
-
-  def __repr__(self):
-    return "<Config> channel: {0._channel}, cachedir: {0._cachedir}, token: ***".format(self)
-
-  @property
-  def cachedir(self):
-    return self._cachedir
-
-  @property
-  def channel(self):
-    return self._channel
-
-  @property
-  def token(self):
-    return self._token
-
-  @property
-  def font(self):
-    return self._font
-
-  @property
-  def logfile(self):
-    return self._logfile
-
-  @property
-  def loglevel(self):
-    return self._loglevel
+  data = {}
+  for name in _data:
+    data[name] = type('Config', (object, ), _data[name])
+  return data
 
 class NoaaData:
   """Data structure storing all the sun indices predictions"""
@@ -329,8 +292,8 @@ def yesno(parg):
   raise argparse.ArgumentError
 
 
-def get_alerts(config, client):
-  alerts = Alerts(config.cachedir)
+def get_alerts(cachedir, channel, client):
+  alerts = Alerts(cachedir)
   if not alerts.newdata:
     logging.info('No new Alert message to post')
     return
@@ -339,40 +302,38 @@ def get_alerts(config, client):
     message = []
     message.append("```" + alerts.text + "```")
     message.append("For more information on the sun activity: https://www.swpc.noaa.gov/communities/space-weather-enthusiasts")
-    client.chat_postMessage(channel=config.channel, text='\n'.join(message))
+    client.chat_postMessage(channel=channel, text='\n'.join(message))
     logging.info("Alerts messages on %s", alerts.time.strftime("%b %d %H:%M"))
   except SlackApiError as err:
     logging.error("postMessage error: %s", err.response['error'])
 
 
-def get_flux(config, client):
-  flux = Flux(config.cachedir)
+def get_flux(cachedir, channel, client):
+  flux = Flux(cachedir)
   if not flux.newdata:
     logging.info('No new flux graph to post')
     return
 
   time_tag = datetime.now().strftime('%Y%m%d%H%M')
   plot_file = 'flux_{}.png'.format(time_tag)
-  plot_path = os.path.join(config.cachedir, plot_file)
+  plot_path = os.path.join(cachedir, plot_file)
   plot(flux, plot_path)
   logging.info('A new plot file %s generated', plot_file)
   try:
     title = 'Previsions for: {}'.format(flux.time.strftime("%b %d %H:%M"))
-    client.files_upload(file=plot_path, channels=config.channel, initial_comment=title)
+    client.files_upload(file=plot_path, channels=channel, initial_comment=title)
     logging.info("Sending plot file: %s", plot_path)
   except SlackApiError as err:
     logging.error("file_upload error: %s", err.response['error'])
 
 
-def get_muf(config, client):
-  # The muf video animation is generated by the animatemuf.py program
-  muf_video = '/var/www/html/muf.mp4'
-  # muf_video = '/Volumes/WDPassport/tmp/muf/muf.mp4'
+def get_muf(muf_video, channel, client):
   if not os.path.exists(muf_video):
+    logging.error("Video file not found: %s", muf_video)
     return
   try:
     title = "MUF for the last 24 hours _click on the image to see the animation_"
-    client.files_upload(file=muf_video, channels=config.channel, initial_comment=title)
+    client.files_upload(file=muf_video, channels=channel, initial_comment=title)
     logging.info("Sending muf animation file: %s", muf_video)
   except SlackApiError as err:
     logging.error("file_upload error: %s", err.response['error'])
@@ -393,18 +354,15 @@ def main():
   parser.add_argument("-m", "--muf", action='store_true',
                       help="MUF previsions map (yes/no) [default: %(default)s]")
   opts = parser.parse_args()
-  config = Config(os.path.expanduser(opts.config))
+  _config = read_config(os.path.expanduser(opts.config))
+  config = _config['sunslack']
+  anim_conf = _config['animatemuf']
+  del _config
 
   logger = logging.getLogger()
   if config.loglevel != logger.level:
     logger.setLevel(config.loglevel)
 
-  if config.logfile:
-    fmt = logging.Formatter('%(asctime)s %(levelname)s: [%(funcName)s] %(message)s')
-    handler = logging.FileHandler(config.logfile, encoding='utf-8')
-    handler.setFormatter(fmt)
-    logger.handlers = [handler]
-
   client = WebClient(token=config.token)
 
   if not any([opts.alerts, opts.flux, opts.muf]):
@@ -412,11 +370,11 @@ def main():
     return
 
   if opts.alerts:
-    get_alerts(config, client)
+    get_alerts(config.cachedir, config.channel, client)
   if opts.flux:
-    get_flux(config, client)
+    get_flux(config.cachedir, config.channel, client)
   if opts.muf:
-    get_muf(config, client)
+    get_muf(anim_conf.video_file, config.channel, client)
 
 
 if __name__ == "__main__":
